/* trace.h
 */
#ifndef OSL_TRACE_H
#define OSL_TRACE_H

// #define OSL_STATIC_INITIALIZER_TRACE

#ifdef OSL_STATIC_INITIALIZER_TRACE
#  include <iostream>
#endif

namespace osl
{
namespace misc
{
  struct StaticInitializeTracer
  {
    StaticInitializeTracer(const char *filename);
  };
} // namespace misc
} // namespace osl

#define OSL_TRACE static osl::misc::StaticInitializeTracer tracer( __FILE__)

#endif /* OSL_TRACE_H */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
